@@ -94,19 +94,19 @@ public:
     /**
       * Destroys this ETMCalendar.
       */
-    ~ETMCalendar();
+    ~ETMCalendar() override;
 
     /**
      * Returns the collection having @p id.
      * Use this instead of creating a new collection, the returned collection will have
      * the correct right, name, display name, etc all set.
      */
-    Akonadi::Collection collection(Akonadi::Collection::Id) const;
+    Q_REQUIRED_RESULT Akonadi::Collection collection(Akonadi::Collection::Id) const;
 
     /**
       * Returns true if the collection owning incidence @p has righ @p right
       */
-    bool hasRight(const Akonadi::Item &item, Akonadi::Collection::Right right) const;
+    Q_REQUIRED_RESULT bool hasRight(const Akonadi::Item &item, Akonadi::Collection::Right right) const;
 
     /**
       * This is an overloaded function.
@@ -114,7 +114,7 @@ public:
       * @param right the access right to check for
       * @see hasRight()
       */
-    bool hasRight(const QString &uid, Akonadi::Collection::Right right) const;
+    Q_REQUIRED_RESULT bool hasRight(const QString &uid, Akonadi::Collection::Right right) const;
 
     /**
      * Returns the KCheckableProxyModel used to select from which collections should
@@ -172,12 +172,12 @@ public:
      * Returns whether collection filtering is enabled. Default is true.
      * @see setCollectionFilteringEnabled()
      */
-    bool collectionFilteringEnabled() const;
+    Q_REQUIRED_RESULT bool collectionFilteringEnabled() const;
 
     /**
       * Returns if the calendar already finished loading.
       */
-    bool isLoaded() const override;
+    Q_REQUIRED_RESULT bool isLoaded() const override;
 
 Q_SIGNALS:
     /**
